@@ -28,13 +28,13 @@ from pitivi.clipproperties import ClipProperties
 from pitivi.configure import APPNAME
 from pitivi.configure import get_ui_dir
 from pitivi.dialogs.missingasset import MissingAssetDialog
+from pitivi.dialogs.projectsettings import ProjectSettingsDialog
 from pitivi.editorstate import EditorState
 from pitivi.effects import EffectListWidget
 from pitivi.interactiveintro import InteractiveIntro
 from pitivi.mediafilespreviewer import PreviewWidget
 from pitivi.medialibrary import MediaLibraryWidget
 from pitivi.perspective import Perspective
-from pitivi.project import ProjectSettingsDialog
 from pitivi.settings import GlobalSettings
 from pitivi.tabsmanager import BaseTabs
 from pitivi.timeline.previewers import ThumbnailCache
@@ -128,6 +128,9 @@ class EditorPerspective(Perspective, Loggable):
             # Nothing to work with, Pitivi is starting up.
             return
 
+        if self.app.project_manager.current_project.pipeline.rendering():
+            return
+
         # Commit the timeline so its nested timelines assets are refreshed.
         ges_timeline.commit()
 
@@ -831,7 +834,7 @@ class PreviewAssetWindow(Gtk.Window):
         self._previewer.preview_uri(self._asset.get_id())
         self._previewer.show()
 
-        self.connect("focus-out-event", self._leave_preview_cb)
+        self.connect("key-press-event", self._key_press_event_cb)
 
     def preview(self):
         """Shows the window and starts the playback."""
@@ -873,6 +876,7 @@ class PreviewAssetWindow(Gtk.Window):
             new_height = max_width * img_height / img_width
             return int(max_width), int(new_height + controls_height)
 
-    def _leave_preview_cb(self, window, unused):
-        self.destroy()
+    def _key_press_event_cb(self, unused_widget, event):
+        if event.keyval == Gdk.KEY_Escape:
+            self.destroy()
         return True
